@@ -292,6 +292,13 @@ Q_SIGNALS:
      */
     void toggleTodoCompletedSignal(const Akonadi::Item &);
 
+    /**
+     * Toggle the completion state of the incidence contained in the item
+     * (which must be a Todo) on the given date.  If the todo recurs, the
+     * QDate identifies the occurrence to toggle.
+     */
+    void toggleOccurrenceCompletedSignal(const Akonadi::Item &, const QDate &);
+
     /**
      * Copy the incidence to the specified resource.
      */
